@@ -1,4 +1,15 @@
-import xmllib
+# Got this script from Liquid War, pathed to be able
+# to transform XML docs into uwikicms content.
+
+# Note that this code used to use the xmllib module
+# which came with python 1.6, however it's now
+# deprecated so I use sax instead. Point is it wasn't
+# designed for sax in the first place, and I haven't
+# much time nor interest to code this, and the direct
+# consequence is that the code is ugly. I know.
+
+import xml.sax
+
 import string
 import re
 
@@ -106,17 +117,49 @@ def format_texi(text):
 
     return result
 
-class XMLToX(xmllib.XMLParser):
+def format_uwc(text):
+    result=text
+
+    result=string.replace(result,"]","]")
+    result=string.replace(result,"[","[[")
+
+    return result
+
+def format_uwc_text(text):
+    result=text
+
+    result=format_uwc(result)
+    
+    # This is an ugly way to get rid of all junk at line start
+    result=format_text(result,0,999999)
+
+    return result
+
+def format_uwc_elem(text):
+    result=text
+
+    result=format_uwc(result)
+    result=string.replace(result,"\n"," ")
+    result=string.replace(result,"\r"," ")
+    result=remove_duplicate_blanks(result)
+
+    return result
+
+def format_uwc_code(text):
+    result=text
+
+    result=format_uwc(result)
+    line=re.compile('^(.*)$',re.M)
+    result=line.sub(r"  \1",result);
+
+    return result
+
+class XMLToX(xml.sax.ContentHandler):
     def __init__(self):
-        xmllib.XMLParser.__init__(self)
+        xml.sax.ContentHandler.__init__(self)
+        self.charbuf=""
         self.translated=""
-        self.elements["file"]=(None,None)
-        self.elements["chap"]=(None,None)
-        self.elements["part"]=(None,None)
-        self.elements["text"]=(None,None)
-        self.elements["list"]=(None,None)
-        self.elements["elem"]=(None,None)
-        self.elements["code"]=(None,None)
+        self.stack=[]
     def write(self,text):
         self.translated=self.translated+text
     def start_file(self,title):
@@ -147,7 +190,9 @@ class XMLToX(xmllib.XMLParser):
         pass
     def end_code(self):
         pass
-    def unknown_starttag(self,tag,attributes):
+    def startElement(self,tag,attributes):
+        self.charbuf=""
+        self.stack.append(tag)
         if tag=="file":
             self.start_file(attributes["title"])
         if tag=="chap":
@@ -162,7 +207,12 @@ class XMLToX(xmllib.XMLParser):
             self.start_elem()
         if tag=="code":
             self.start_code()
-    def unknown_endtag(self,tag):
+    def endElement(self,tag):
+        data=string.strip(self.charbuf)
+        if (data!=""):
+            self.write(self.translate(data,self.stack[-1]))
+        self.charbuf=""
+        self.stack=self.stack[:-1]
         if tag=="file":
             self.end_file()
         elif tag=="chap":
@@ -179,13 +229,8 @@ class XMLToX(xmllib.XMLParser):
             self.end_code()
     def translate(self,data,tag):
         return data
-    def handle_data(self,data):
-        if len(self.stack)>0:
-            data=string.strip(data)
-            if (data!=''):
-                #print data
-                #print self.stack
-                self.write(self.translate(data,self.stack[-1][0]))
+    def characters(self,data):
+        self.charbuf+=data
 
 class XMLToHTML(XMLToX):
     def __init__(self,header,footer):
@@ -467,47 +512,107 @@ class XMLToTexi(XMLToX):
         result=format_texi(result)
         return result
 
-def run_parser(parser,dst,src):
+class XMLToUWC(XMLToX):
+    def __init__(self):
+        XMLToX.__init__(self)
+    def start_file(self,title):
+        # In UWikKiCMS document is handled manually once for
+        # all directly in the UWiKiCMS site/instance.
+        pass
+    def start_chap(self,title):
+        self.write("\n!! "+title+"\n");
+    def start_part(self,title):
+        self.write("\n! "+title+"\n");
+    def start_text(self):
+        self.write("\n")
+    def start_list(self):
+        self.write("\n")
+    def start_elem(self):
+        self.write("\n* ")
+    def start_code(self):
+        self.write("\n")
+    def end_file(self):
+        self.write("\n")
+    def end_chap(self):
+        self.write("\n")
+    def end_part(self):
+        self.write("\n")
+    def end_text(self):
+        self.write("\n")
+    def end_list(self):
+        self.write("\n")
+    def end_elem(self):
+        # No \n for we do not want blank lines between elems
+        pass
+    def end_code(self):
+        self.write("\n")
+    def translate(self,data,tag):
+        result=data
+	result=format_email_and_url(result)
+
+        if (tag=="code"):
+            result=format_uwc_code(result)
+        elif (tag=="elem"):
+            result=format_uwc_elem(result)
+        else:
+            result=format_uwc_text(result)        
+
+        return result
+
+def run_parser(handler,dst,src):
     dst_file=open(dst,"w")
     src_file=open(src,"r")
-    src_code=src_file.read()
-    parser.feed(src_code)
-    dst_code=parser.translated
-    dst_file.write(dst_code)
+    #src_code=src_file.read()
+    parser=xml.sax.make_parser()
+    parser.setContentHandler(handler)
+    parser.parse(src_file)
+    dst_code=handler.translated
+    dst_file.write(dst_code.encode("iso-8859-1"))
     src_file.close()
     dst_file.close()
         
-def make_html(html,xml,header,footer):
+def make_html(html_file,xml_file,header,footer):
     header_file=open(header,"r")
     footer_file=open(footer,"r")
     header_str=header_file.read()
     footer_str=footer_file.read()
-    parser=XMLToHTML(header_str,footer_str)
-    run_parser(parser,html,xml)
+    handler=XMLToHTML(header_str,footer_str)
+    run_parser(handler,html_file,xml_file)
     header_file.close()
     footer_file.close()
 
-def make_php3(php3,xml):
-    parser=XMLToPHP3()
-    run_parser(parser,php3,xml)
+def make_php3(php3_file,xml_file):
+    parser=xml.sax.make_parser()
+    handler=(XMLToPHP3())
+    run_parser(handler,php3_file,xml_file)
 
-def make_tex(tex,xml):
-    parser=XMLToTeX()
-    run_parser(parser,tex,xml)
+def make_tex(tex_file,xml_file):
+    parser=xml.sax.make_parser()
+    handler=XMLToTeX()
+    run_parser(handler,tex_file,xml_file)
 
-def make_man(man,xml):
-    parser=XMLToMan()
-    run_parser(parser,man,xml)
+def make_man(man_file,xml_file):
+    parser=xml.sax.make_parser()
+    handler=XMLToMan()
+    run_parser(handler,man_file,xml_file)
 
-def make_txt(txt,xml,header):
-    parser=XMLToTxt(header)
-    run_parser(parser,txt,xml)
+def make_txt(txt_file,xml_file,header):
+    parser=xml.sax.make_parser()
+    handler=XMLToTxt(header)
+    run_parser(handler,txt_file,xml_file)
 
-def make_texi(texi,xml):
-    node=string.replace(xml,".xml","")
+def make_texi(texi_file,xml_file):
+    node=string.replace(xml_file,".xml","")
     node=string.replace(node,"xml/","")
-    parser=XMLToTexi(node)
-    run_parser(parser,texi,xml)
+    parser=xml.sax.make_parser()
+    handler=XMLToTexi(node)
+    run_parser(handler,texi_file,xml_file)
+
+def make_uwc(uwc_file,xml_file):
+    parser=xml.sax.make_parser()
+    handler=XMLToUWC()
+    run_parser(handler,uwc_file,xml_file)
+
 
 
 
