@@ -22,7 +22,7 @@
 
 /*****************************************************************************/
 /* Liquid War is a multiplayer wargame                                       */
-/* Copyright (C) 1998-2004 Christian Mauduit                                 */
+/* Copyright (C) 1998-2007 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -36,9 +36,9 @@
 /*                                                                           */
 /* You should have received a copy of the GNU General Public License         */
 /* along with this program; if not, write to the Free Software               */
-/* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
+/* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 /*                                                                           */
-/* Liquid War homepage : http://www.ufoot.org/liquidwar                      */
+/* Liquid War homepage : http://www.ufoot.org/liquidwar/v5                   */
 /* Contact author      : ufoot@ufoot.org                                     */
 /*****************************************************************************/
 
@@ -124,7 +124,7 @@ lw_basicopt_legal_info (char *name)
   log_println_str (name);
   log_println ();
   log_println_str ("v" LW_VERSION " compiled on " __DATE__ " at " __TIME__);
-  log_println_str ("Copyright (C) 1998-2004 Christian Mauduit");
+  log_println_str ("Copyright (C) 1998-2007 Christian Mauduit");
   log_println ();
   log_println_str
     ("This program is free software; you can redistribute it and/or modify");
@@ -149,8 +149,8 @@ lw_basicopt_legal_info (char *name)
   log_println_str
     ("along with this program; if not, write to the Free Software");
   log_println_str
-    ("Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA");
+    ("Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA");
   log_println ();
-  log_println_str ("Liquid War homepage : http://www.ufoot.org/liquidwar");
+  log_println_str ("Liquid War homepage : http://www.ufoot.org/liquidwar/v5");
   log_println_str ("Contact author      : ufoot@ufoot.org");
 }
