@@ -22,7 +22,7 @@
 
 /*****************************************************************************/
 /* Liquid War is a multiplayer wargame                                       */
-/* Copyright (C) 1998-2004 Christian Mauduit                                 */
+/* Copyright (C) 1998-2007 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -36,9 +36,9 @@
 /*                                                                           */
 /* You should have received a copy of the GNU General Public License         */
 /* along with this program; if not, write to the Free Software               */
-/* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
+/* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 /*                                                                           */
-/* Liquid War homepage : http://www.ufoot.org/liquidwar                      */
+/* Liquid War homepage : http://www.ufoot.org/liquidwar/v5                   */
 /* Contact author      : ufoot@ufoot.org                                     */
 /*****************************************************************************/
 
@@ -126,7 +126,7 @@ static void
 lock_sound (SAMPLE * smp)
 {
   LOCK_VARIABLE (*smp);
-#ifdef ALLEGRO_DOS
+#ifdef DOS
   _go32_dpmi_lock_data (smp->data, (smp->bits / 8) * smp->len);
 #else
   LW_MACRO_NOP (smp);
@@ -313,7 +313,7 @@ load_dat (void)
   log_print_str (STARTUP_DAT_PATH);
   log_print_str ("\"");
 
-#ifdef ALLEGRO_DOS
+#ifdef DOS
   loadable = 1;
 #else
   loadable = exists (STARTUP_DAT_PATH);
@@ -434,8 +434,8 @@ load_dat (void)
 }
 
 /*------------------------------------------------------------------*/
-static void
-load_custom_texture_callback (const char *file, int mode, int unused)
+static int
+load_custom_texture_callback (const char *file, int mode, void *unused)
 {
   void *pointeur;
 
@@ -453,6 +453,8 @@ load_custom_texture_callback (const char *file, int mode, int unused)
       log_print_str ("-");
     }
   log_flush ();
+
+  return 0;
 }
 
 /*------------------------------------------------------------------*/
@@ -468,15 +470,15 @@ load_custom_texture (void)
   fix_filename_slashes (buf);
 
   CUSTOM_TEXTURE_OK = 0;
-  for_each_file (buf, FA_RDONLY | FA_ARCH, load_custom_texture_callback, 0);
+  for_each_file_ex (buf, 0, FA_DIREC, load_custom_texture_callback, NULL);
   result = CUSTOM_TEXTURE_OK;
 
   return result;
 }
 
 /*------------------------------------------------------------------*/
-static void
-load_custom_map_callback (const char *file, int mode, int unused)
+static int
+load_custom_map_callback (const char *file, int mode, void *unused)
 {
   void *pointeur;
 
@@ -493,6 +495,8 @@ load_custom_map_callback (const char *file, int mode, int unused)
     {
       log_print_str ("-");
     }
+
+  return 0;
 }
 
 /*------------------------------------------------------------------*/
@@ -508,15 +512,15 @@ load_custom_map (void)
   fix_filename_slashes (buf);
 
   CUSTOM_MAP_OK = 0;
-  for_each_file (buf, FA_RDONLY | FA_ARCH, load_custom_map_callback, 0);
+  for_each_file_ex (buf, 0, FA_DIREC, load_custom_map_callback, NULL);
   result = CUSTOM_MAP_OK;
 
   return result;
 }
 
 /*------------------------------------------------------------------*/
-static void
-load_custom_music_callback (const char *file, int mode, int unused)
+static int
+load_custom_music_callback (const char *file, int mode, void *unused)
 {
   void *pointeur;
 
@@ -534,6 +538,8 @@ load_custom_music_callback (const char *file, int mode, int unused)
       log_print_str ("-");
     }
   log_flush ();
+
+  return 0;
 }
 
 /*------------------------------------------------------------------*/
@@ -549,7 +555,7 @@ load_custom_music (void)
   fix_filename_slashes (buf);
 
   CUSTOM_MUSIC_OK = 0;
-  for_each_file (buf, FA_RDONLY | FA_ARCH, load_custom_music_callback, 0);
+  for_each_file_ex (buf, 0, FA_DIREC, load_custom_music_callback, NULL);
   result = CUSTOM_MUSIC_OK;
 
   return result;
