@@ -22,7 +22,7 @@
 
 /*****************************************************************************/
 /* Liquid War is a multiplayer wargame                                       */
-/* Copyright (C) 1998-2005 Christian Mauduit                                 */
+/* Copyright (C) 1998-2007 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -36,9 +36,9 @@
 /*                                                                           */
 /* You should have received a copy of the GNU General Public License         */
 /* along with this program; if not, write to the Free Software               */
-/* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
+/* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 /*                                                                           */
-/* Liquid War homepage : http://www.ufoot.org/liquidwar                      */
+/* Liquid War homepage : http://www.ufoot.org/liquidwar/v5                   */
 /* Contact author      : ufoot@ufoot.org                                     */
 /*****************************************************************************/
 
@@ -58,9 +58,14 @@
 #include "popupgen.h"
 #endif
 
+#ifdef DOS
+#include <conio.h>
+#endif
+
 #include "basicopt.h"
 #include "config.h"
 #include "exit.h"
+#include "init.h"
 #include "log.h"
 #include "sound.h"
 #include "startup.h"
@@ -90,28 +95,32 @@ static int LW_EXIT_FORCE_SHUTDOWN = 0;
 static void
 exit_all (void)
 {
-  /*
-   * we take a rest before and after calling set_gfx_mode(GFX_TEXT,...)
-   * This is an attempt to get rid of a hideous bug under X-Win,
-   * which said that there was a "bad file descriptor"
-   */
-  rest (10);
-  last_flip ();
-  set_gfx_mode (GFX_TEXT, 0, 0, 0, 0);
-  rest (10);
+  if (LW_INIT_ALLEGRO_OK)
+    {
+      /*
+       * we take a rest before and after calling set_gfx_mode(GFX_TEXT,...)
+       * This is an attempt to get rid of a hideous bug under X-Win,
+       * which said that there was a "bad file descriptor"
+       */
+      rest (10);
+      last_flip ();
+      set_gfx_mode (GFX_TEXT, 0, 0, 0, 0);
+      rest (10);
 
-  log_println ();
-  log_println_str ("Leaving Allegro (http://www.talula.demon.co.uk/allegro)");
-  save_config_options ();
-  stop_water ();
-  stop_ticker ();
-  remove_sound ();
-  remove_mouse ();
-  clear_keybuf ();
-  remove_keyboard ();
-  remove_timer ();
-  allegro_exit ();
-  lw_sock_exit ();
+      log_println ();
+      log_println_str
+	("Leaving Allegro (http://www.talula.demon.co.uk/allegro)");
+      save_config_options ();
+      stop_water ();
+      stop_ticker ();
+      remove_sound ();
+      remove_mouse ();
+      clear_keybuf ();
+      remove_keyboard ();
+      remove_timer ();
+      allegro_exit ();
+      lw_sock_exit ();
+    }
 }
 
 /*------------------------------------------------------------------*/
