@@ -22,7 +22,7 @@
 
 /*****************************************************************************/
 /* Liquid War is a multiplayer wargame                                       */
-/* Copyright (C) 1998-2004 Christian Mauduit                                 */
+/* Copyright (C) 1998-2007 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -36,9 +36,9 @@
 /*                                                                           */
 /* You should have received a copy of the GNU General Public License         */
 /* along with this program; if not, write to the Free Software               */
-/* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
+/* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 /*                                                                           */
-/* Liquid War homepage : http://www.ufoot.org/liquidwar                      */
+/* Liquid War homepage : http://www.ufoot.org/liquidwar/v5                   */
 /* Contact author      : ufoot@ufoot.org                                     */
 /*****************************************************************************/
 
@@ -129,11 +129,11 @@ lw_httputil_get_page (char *content, char *url, int size)
     {
       if (lw_sock_connect (&sock, ip, LW_HTTPUTIL_PORT))
 	{
-	  if (lw_sock_send_str (sock, request))
+	  if (lw_sock_send_str (&sock, request))
 	    {
 	      result = 1;
 	      /* read status line */
-	      if (result && lw_sock_recv_str (sock, data) != 1)
+	      if (result && lw_sock_recv_str (&sock, data) != 1)
 		{
 		  result = 0;
 		  LW_MACRO_SNPRINTF0 (content, size,
@@ -152,8 +152,8 @@ lw_httputil_get_page (char *content, char *url, int size)
 		{
 		  /* skip past headers */
 		  while ((result =
-			  (result && (lw_sock_recv_str (sock, data) == 1))) &&
-			 data[0])
+			  (result && (lw_sock_recv_str (&sock, data) == 1)))
+			 && data[0])
 		    {
 		      /* nothing to do here */
 		    }
@@ -161,7 +161,7 @@ lw_httputil_get_page (char *content, char *url, int size)
 		  if (result)
 		    {
 		      /* finally, we read the list of servers */
-		      while (lw_sock_recv_str (sock, data) == 1 &&
+		      while (lw_sock_recv_str (&sock, data) == 1 &&
 			     empty_lines < LW_HTTPUTIL_EMPTY_LINES_LIMIT)
 			{
 			  data_len = strlen (data);
