@@ -22,7 +22,7 @@
 
 /*****************************************************************************/
 /* Liquid War is a multiplayer wargame                                       */
-/* Copyright (C) 1998-2004 Christian Mauduit                                 */
+/* Copyright (C) 1998-2007 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -36,9 +36,9 @@
 /*                                                                           */
 /* You should have received a copy of the GNU General Public License         */
 /* along with this program; if not, write to the Free Software               */
-/* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
+/* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 /*                                                                           */
-/* Liquid War homepage : http://www.ufoot.org/liquidwar                      */
+/* Liquid War homepage : http://www.ufoot.org/liquidwar/v5                   */
 /* Contact author      : ufoot@ufoot.org                                     */
 /*****************************************************************************/
 
@@ -81,7 +81,7 @@ MESHER;
 #define MESH_FG 1
 #define MESH_BG 2
 
-#define MESH_MAX_ELEM_SIZE 8
+#define MESH_MAX_ELEM_SIZE 16
 
 MESH *CURRENT_MESH = NULL;
 int CURRENT_MESH_SIZE = 0;
@@ -128,26 +128,29 @@ create_first_mesher (BITMAP * map)
 	  {
 	    i = y * w + x;
 
-	    if (result[i - w].used)
-	      result[i].link[DIR_NNW] = result[i].link[DIR_NNE]
-		= result + i - w;
-	    if (result[i - w + 1].used)
-	      result[i].link[DIR_NE] = result + i - w + 1;
-	    if (result[i + 1].used)
-	      result[i].link[DIR_ENE] = result[i].link[DIR_ESE]
-		= result + i + 1;
-	    if (result[i + w + 1].used)
-	      result[i].link[DIR_SE] = result + i + w + 1;
-	    if (result[i + w].used)
-	      result[i].link[DIR_SSE] = result[i].link[DIR_SSW]
-		= result + i + w;
-	    if (result[i + w - 1].used)
-	      result[i].link[DIR_SW] = result + i + w - 1;
-	    if (result[i - 1].used)
-	      result[i].link[DIR_WSW] = result[i].link[DIR_WNW]
-		= result + i - 1;
-	    if (result[i - w - 1].used)
-	      result[i].link[DIR_NW] = result + i - w - 1;
+	    if (result[i].used)
+	      {
+		if (result[i - w].used)
+		  result[i].link[DIR_NNW] = result[i].link[DIR_NNE]
+		    = result + i - w;
+		if (result[i - w + 1].used)
+		  result[i].link[DIR_NE] = result + i - w + 1;
+		if (result[i + 1].used)
+		  result[i].link[DIR_ENE] = result[i].link[DIR_ESE]
+		    = result + i + 1;
+		if (result[i + w + 1].used)
+		  result[i].link[DIR_SE] = result + i + w + 1;
+		if (result[i + w].used)
+		  result[i].link[DIR_SSE] = result[i].link[DIR_SSW]
+		    = result + i + w;
+		if (result[i + w - 1].used)
+		  result[i].link[DIR_SW] = result + i + w - 1;
+		if (result[i - 1].used)
+		  result[i].link[DIR_WSW] = result[i].link[DIR_WNW]
+		    = result + i - 1;
+		if (result[i - w - 1].used)
+		  result[i].link[DIR_NW] = result + i - w - 1;
+	      }
 	  }
     }
 
@@ -170,8 +173,8 @@ group_mesher (MESHER * mesher, BITMAP * map, int step)
   h = map->h;
   size = h * w;
 
-  for (y = 0; y < h; y += step * 2)
-    for (x = 0; x < w; x += step * 2)
+  for (y = 0; y < h - step; y += step * 2)
+    for (x = 0; x < w - step; x += step * 2)
       {
 	i = y * w + x;
 	ne = mesher + i + step;
@@ -357,7 +360,7 @@ create_mesh (void)
       if (mesher != NULL)
 	{
 	  i = 1;
-	  while (i <= MESH_MAX_ELEM_SIZE && group_mesher (mesher, map, i))
+	  while (i <= MESH_MAX_ELEM_SIZE / 2 && group_mesher (mesher, map, i))
 	    i *= 2;
 	  CURRENT_MESH = mesher_to_mesh (mesher, map,
 					 &CURRENT_MESH_SIZE,
