@@ -22,7 +22,7 @@
 
 /*****************************************************************************/
 /* Liquid War is a multiplayer wargame                                       */
-/* Copyright (C) 1998-2004 Christian Mauduit                                 */
+/* Copyright (C) 1998-2007 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -36,9 +36,9 @@
 /*                                                                           */
 /* You should have received a copy of the GNU General Public License         */
 /* along with this program; if not, write to the Free Software               */
-/* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
+/* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 /*                                                                           */
-/* Liquid War homepage : http://www.ufoot.org/liquidwar                      */
+/* Liquid War homepage : http://www.ufoot.org/liquidwar/v5                   */
 /* Contact author      : ufoot@ufoot.org                                     */
 /*****************************************************************************/
 
@@ -112,11 +112,11 @@ display_message (void)
     }
 
   h = text_height (font);
-  text_mode (-1);
+  //text_mode (-1); deprecated
   for (i = 0; i < MESSAGE_NB; ++i)
-    textout (NEXT_SCREEN, font, MESSAGE[i],
-	     NEXT_SCREEN->w - text_length (font, MESSAGE[i]),
-	     NEXT_SCREEN->h - (MESSAGE_NB - i) * h, -1);
+    textout_ex (NEXT_SCREEN, font, MESSAGE[i],
+		NEXT_SCREEN->w - text_length (font, MESSAGE[i]),
+		NEXT_SCREEN->h - (MESSAGE_NB - i) * h, -1, -1);
 }
 
 /*------------------------------------------------------------------*/
