@@ -22,7 +22,7 @@
 
 /*****************************************************************************/
 /* Liquid War is a multiplayer wargame                                       */
-/* Copyright (C) 1998-2004 Christian Mauduit                                 */
+/* Copyright (C) 1998-2007 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -36,9 +36,9 @@
 /*                                                                           */
 /* You should have received a copy of the GNU General Public License         */
 /* along with this program; if not, write to the Free Software               */
-/* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
+/* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 /*                                                                           */
-/* Liquid War homepage : http://www.ufoot.org/liquidwar                      */
+/* Liquid War homepage : http://www.ufoot.org/liquidwar/v5                   */
 /* Contact author      : ufoot@ufoot.org                                     */
 /*****************************************************************************/
 
@@ -62,14 +62,14 @@
 /* variables globales                                               */
 /*==================================================================*/
 
-int MOUSE_CONTROL_REF_X;
-int MOUSE_CONTROL_REF_Y;
-int MOUSE_CONTROL_UP;
-int MOUSE_CONTROL_RIGHT;
-int MOUSE_CONTROL_DOWN;
-int MOUSE_CONTROL_LEFT;
+int MOUSE_CONTROL_REF_X = 0;
+int MOUSE_CONTROL_REF_Y = 0;
+int MOUSE_CONTROL_UP = 0;
+int MOUSE_CONTROL_RIGHT = 0;
+int MOUSE_CONTROL_DOWN = 0;
+int MOUSE_CONTROL_LEFT = 0;
 
-static int MOUSE_CONTROL_GAP;
+static int MOUSE_CONTROL_GAP = 1000;
 static int MOUSE_ON = 1;
 
 /*==================================================================*/
