@@ -22,7 +22,7 @@
 
 /*****************************************************************************/
 /* Liquid War is a multiplayer wargame                                       */
-/* Copyright (C) 1998-2004 Christian Mauduit                                 */
+/* Copyright (C) 1998-2007 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -36,9 +36,9 @@
 /*                                                                           */
 /* You should have received a copy of the GNU General Public License         */
 /* along with this program; if not, write to the Free Software               */
-/* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
+/* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 /*                                                                           */
-/* Liquid War homepage : http://www.ufoot.org/liquidwar                      */
+/* Liquid War homepage : http://www.ufoot.org/liquidwar/v5                   */
 /* Contact author      : ufoot@ufoot.org                                     */
 /*****************************************************************************/
 
@@ -83,7 +83,7 @@
  * Sends a map over the network
  */
 int
-lw_netmap_send (int sock, void *netmap)
+lw_netmap_send (int *sock, void *netmap)
 {
   int result = 0;
   char *ptr;
@@ -137,7 +137,7 @@ lw_netmap_send (int sock, void *netmap)
  * Receives a map from the network
  */
 int
-lw_netmap_recv (int sock, void **netmap)
+lw_netmap_recv (int *sock, void **netmap)
 {
   int result = 0;
   char buffer[8 + LW_MAP_SYSTEM_NAME_SIZE + LW_MAP_READABLE_NAME_SIZE];
