@@ -22,7 +22,7 @@
 
 /*****************************************************************************/
 /* Liquid War is a multiplayer wargame                                       */
-/* Copyright (C) 1998-2004 Christian Mauduit                                 */
+/* Copyright (C) 1998-2007 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -36,9 +36,9 @@
 /*                                                                           */
 /* You should have received a copy of the GNU General Public License         */
 /* along with this program; if not, write to the Free Software               */
-/* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
+/* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 /*                                                                           */
-/* Liquid War homepage : http://www.ufoot.org/liquidwar                      */
+/* Liquid War homepage : http://www.ufoot.org/liquidwar/v5                   */
 /* Contact author      : ufoot@ufoot.org                                     */
 /*****************************************************************************/
 
@@ -298,7 +298,7 @@ connect_on_server_continue (int sock)
   if (result == 1)
     {
       display_center_message (lw_lang_string (LW_LANG_STRING_NETPLAY_PING));
-      if (!lw_protocol_do_ping (sock))
+      if (!lw_protocol_do_ping (&sock))
 	{
 	  result = 0;
 	  error_not_a_liquidwar_server ();
@@ -309,7 +309,7 @@ connect_on_server_continue (int sock)
     {
       display_center_message (lw_lang_string
 			      (LW_LANG_STRING_NETPLAY_CHECKPROGRAM));
-      if (!lw_protocol_tell_program (sock, LW_PROGRAM))
+      if (!lw_protocol_tell_program (&sock, LW_PROGRAM))
 	{
 	  result = 0;
 	  error_not_a_liquidwar_server ();
@@ -319,7 +319,7 @@ connect_on_server_continue (int sock)
     {
       display_center_message (lw_lang_string
 			      (LW_LANG_STRING_NETPLAY_CHECKVERSION));
-      if (!lw_protocol_tell_version (sock, LW_VERSION))
+      if (!lw_protocol_tell_version (&sock, LW_VERSION))
 	{
 	  result = 0;
 	  error_wrong_version ();
@@ -330,7 +330,7 @@ connect_on_server_continue (int sock)
     {
       display_center_message (lw_lang_string
 			      (LW_LANG_STRING_NETPLAY_SENDPASSWORD));
-      if (!lw_protocol_tell_password (sock, CONFIG_PASSWORD))
+      if (!lw_protocol_tell_password (&sock, CONFIG_PASSWORD))
 	{
 	  result = 0;
 	  error_bad_password ();
@@ -341,7 +341,7 @@ connect_on_server_continue (int sock)
     {
       display_center_message (lw_lang_string
 			      (LW_LANG_STRING_NETPLAY_FREETEAMS));
-      if (lw_protocol_ask_free_teams (sock, &free_teams))
+      if (lw_protocol_ask_free_teams (&sock, &free_teams))
 	{
 	  if (free_teams <= 0)
 	    {
@@ -366,7 +366,7 @@ connect_on_server_continue (int sock)
 	      ((CONFIG_CONTROL_TYPE[i] == CONFIG_CONTROL_TYPE_CPU) &&
 	       CONFIG_ALLOW_NETWORK_BOTS))
 	    {
-	      if (lw_protocol_reserve_team (sock, i,
+	      if (lw_protocol_reserve_team (&sock, i,
 					    CONFIG_CONTROL_TYPE[i],
 					    CONFIG_PLAYER_NAME[i]))
 		{
@@ -385,7 +385,7 @@ connect_on_server_continue (int sock)
     {
       display_center_message (lw_lang_string
 			      (LW_LANG_STRING_NETPLAY_SENDCONFIG));
-      if (!lw_protocol_send_config (sock))
+      if (!lw_protocol_send_config (&sock))
 	{
 	  result = 0;
 	  error_network_problem ();
@@ -397,7 +397,7 @@ connect_on_server_continue (int sock)
       display_center_message (lw_lang_string
 			      (LW_LANG_STRING_NETPLAY_SENDMAP));
       if (!lw_protocol_send_map
-	  (sock,
+	  (&sock,
 	   LW_RANDOM_ON ? LW_RANDOM_RAW_MAP :
 	   RAW_MAP_ORDERED[CONFIG_LEVEL_MAP]))
 	{
@@ -410,7 +410,7 @@ connect_on_server_continue (int sock)
     {
       display_center_message (lw_lang_string
 			      (LW_LANG_STRING_NETPLAY_WAITING));
-      if (!lw_protocol_i_am_ready (sock))
+      if (!lw_protocol_i_am_ready (&sock))
 	{
 	  result = 0;
 	  error_network_problem ();
@@ -451,7 +451,7 @@ connect_on_server_finish (int sock)
 			      (LW_LANG_STRING_NETPLAY_WHOPLAYS));
       for (i = 0; i < NB_TEAMS && result == 1; ++i)
 	{
-	  if (!lw_protocol_ask_who (sock, i, &(LW_NETWORK_INFO[i])))
+	  if (!lw_protocol_ask_who (&sock, i, &(LW_NETWORK_INFO[i])))
 	    {
 	      result = 0;
 	      error_network_problem ();
@@ -463,7 +463,7 @@ connect_on_server_finish (int sock)
     {
       display_center_message (lw_lang_string
 			      (LW_LANG_STRING_NETPLAY_RECVCONFIG));
-      if (!lw_protocol_recv_config (sock))
+      if (!lw_protocol_recv_config (&sock))
 	{
 	  result = 0;
 	  error_network_problem ();
@@ -483,7 +483,7 @@ connect_on_server_finish (int sock)
     {
       display_center_message (lw_lang_string
 			      (LW_LANG_STRING_NETPLAY_RECVMAP));
-      if (!lw_protocol_recv_map (sock, &LW_NETWORK_RAW_MAP))
+      if (!lw_protocol_recv_map (&sock, &LW_NETWORK_RAW_MAP))
 	{
 	  result = 0;
 	  error_cant_receive_map ();
@@ -494,7 +494,7 @@ connect_on_server_finish (int sock)
     {
       display_center_message (lw_lang_string
 			      (LW_LANG_STRING_NETPLAY_WAITING));
-      if (!lw_protocol_i_am_ready (sock))
+      if (!lw_protocol_i_am_ready (&sock))
 	{
 	  result = 0;
 	  error_network_problem ();
