@@ -22,7 +22,7 @@
 
 /*****************************************************************************/
 /* Liquid War is a multiplayer wargame                                       */
-/* Copyright (C) 1998-2004 Christian Mauduit                                 */
+/* Copyright (C) 1998-2007 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -36,9 +36,9 @@
 /*                                                                           */
 /* You should have received a copy of the GNU General Public License         */
 /* along with this program; if not, write to the Free Software               */
-/* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
+/* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 /*                                                                           */
-/* Liquid War homepage : http://www.ufoot.org/liquidwar                      */
+/* Liquid War homepage : http://www.ufoot.org/liquidwar/v5                   */
 /* Contact author      : ufoot@ufoot.org                                     */
 /*****************************************************************************/
 
@@ -135,31 +135,32 @@ clean_buffer (char *buffer, int len)
  * Returns true if the given number bytes is available on the socket
  */
 int
-lw_sock_peek_ex (int sock, int len)
+lw_sock_peek_ex (int *sock, int len)
 {
   int result = 0;
   int res;
   fd_set read;
   struct timeval tv;
   char buffer[LW_SOCK_MESSAGE_SIZE];
+  int sock_copy;
 
-  if (sock >= 0)
+  if ((sock_copy = *sock) >= 0)
     {
       if (len <= LW_SOCK_MESSAGE_SIZE - 1)
 	{
 	  FD_ZERO (&read);
-	  FD_SET (sock, &read);
+	  FD_SET (sock_copy, &read);
 	  tv.tv_sec = 0;
 	  tv.tv_usec = 0;
-	  res = select (sock + 1, &read, NULL, NULL, &tv);
+	  res = select (sock_copy + 1, &read, NULL, NULL, &tv);
 	  if (res > 0)
 	    {
-	      if (FD_ISSET (sock, &read))
+	      if (FD_ISSET (sock_copy, &read))
 		{
 		  /* 
 		   * First we test if there's enough data available
 		   */
-		  if (recv (sock, buffer, len, MSG_PEEK) == len)
+		  if (recv (sock_copy, buffer, len, MSG_PEEK) == len)
 		    {
 		      result = 1;
 		    }
@@ -179,11 +180,12 @@ lw_sock_peek_ex (int sock, int len)
  * adds a tailing CR+LF so that the message is "telnet/http compliant"
  */
 int
-lw_sock_send_str_ex (int sock, char *str)
+lw_sock_send_str_ex (int *sock, char *str)
 {
   int result = 0;
   int len;
   char buffer[LW_SOCK_MESSAGE_SIZE];
+  int sock_copy;
   fd_set write;
   struct timeval tv;
   int res;
@@ -193,7 +195,7 @@ lw_sock_send_str_ex (int sock, char *str)
   int winerr;
 #endif
 
-  if (sock >= 0)
+  if ((sock_copy = *sock) >= 0)
     {
       result = 1;
 
@@ -211,15 +213,15 @@ lw_sock_send_str_ex (int sock, char *str)
       buffer[len] = '\0';
 
       total_sent = 0;
-      while (total_sent < len && result)
+      while (total_sent < len && result && (sock_copy = *sock) >= 0)
 	{
 	  FD_ZERO (&write);
-	  FD_SET (sock, &write);
+	  FD_SET (sock_copy, &write);
 	  tv.tv_sec = LW_SOCK_SEND_SEC;
 	  tv.tv_usec = LW_SOCK_SEND_USEC;
 
 	  errno = 0;
-	  res = select (sock + 1, NULL, &write, NULL, &tv);
+	  res = select (sock_copy + 1, NULL, &write, NULL, &tv);
 
 	  switch (res)
 	    {
@@ -238,10 +240,11 @@ lw_sock_send_str_ex (int sock, char *str)
 #endif
 	      break;
 	    case 1:
-	      if (FD_ISSET (sock, &write))
+	      if (FD_ISSET (sock_copy, &write))
 		{
 		  sent =
-		    send (sock, buffer + total_sent, len - total_sent, 0);
+		    send (sock_copy, buffer + total_sent, len - total_sent,
+			  0);
 		  if (sent > 0 && sent <= len - total_sent)
 		    {
 		      total_sent += sent;
@@ -262,7 +265,7 @@ lw_sock_send_str_ex (int sock, char *str)
 	  switch (result)
 	    {
 	    case 1:
-	      log_print_int (sock);
+	      log_print_int (sock_copy);
 	      log_print_str (" > \"");
 	      log_print_str (str);
 	      log_print_str ("\"");
@@ -270,12 +273,12 @@ lw_sock_send_str_ex (int sock, char *str)
 	      log_flush ();
 	      break;
 	    case 0:
-	      log_print_int (sock);
+	      log_print_int (sock_copy);
 	      log_print_str (" > timeout!");
 	      log_println ();
 	      break;
 	    default:
-	      log_print_int (sock);
+	      log_print_int (sock_copy);
 	      log_print_str (" > unexpected error!");
 	      log_println ();
 	      break;
@@ -299,13 +302,14 @@ lw_sock_send_str_ex (int sock, char *str)
  * an error.
  */
 int
-lw_sock_recv_str_ex (int sock, char *str)
+lw_sock_recv_str_ex (int *sock, char *str)
 {
   int result = 0;
   int pos, l;
   int cr_found;
   char *cr;
   fd_set read;
+  int sock_copy;
   struct timeval tv;
   int res;
 #ifdef WIN32
@@ -314,7 +318,7 @@ lw_sock_recv_str_ex (int sock, char *str)
 
   str[0] = '\0';
 
-  if (sock >= 0)
+  if ((sock_copy = *sock) >= 0)
     {
       result = 1;
 
@@ -326,15 +330,16 @@ lw_sock_recv_str_ex (int sock, char *str)
        */
       cr_found = 0;
       pos = 0;
-      while (!cr_found && pos < LW_SOCK_MESSAGE_SIZE - 1 && result > 0)
+      while (!cr_found && pos < LW_SOCK_MESSAGE_SIZE - 1 && result > 0
+	     && (sock_copy = *sock) >= 0)
 	{
 	  FD_ZERO (&read);
-	  FD_SET (sock, &read);
+	  FD_SET (sock_copy, &read);
 	  tv.tv_sec = LW_SOCK_RECV_SEC;
 	  tv.tv_usec = LW_SOCK_RECV_USEC;
 
 	  errno = 0;
-	  res = select (sock + 1, &read, NULL, NULL, &tv);
+	  res = select (sock_copy + 1, &read, NULL, NULL, &tv);
 
 	  switch (res)
 	    {
@@ -358,7 +363,7 @@ lw_sock_recv_str_ex (int sock, char *str)
 	       * we are polling. If the event is not for us, let's consider
 	       * everything is fine...
 	       */
-	      if (!FD_ISSET (sock, &read))
+	      if (!FD_ISSET (sock_copy, &read))
 		{
 		  result = 1;
 		}
@@ -375,7 +380,7 @@ lw_sock_recv_str_ex (int sock, char *str)
 		   * along with it, which caused some network inconsistency
 		   * since the messages had "disappeared".
 		   */
-		  if ((l = recv (sock, str + pos, 1, 0)) <= 0)
+		  if ((l = recv (sock_copy, str + pos, 1, 0)) <= 0)
 		    {
 		      /*
 		       * OK, now we have received a message on this socket
@@ -442,7 +447,7 @@ lw_sock_recv_str_ex (int sock, char *str)
 	  switch (result)
 	    {
 	    case 1:
-	      log_print_int (sock);
+	      log_print_int (sock_copy);
 	      log_print_str (" < \"");
 	      log_print_str (str);
 	      log_print_str ("\"");
@@ -450,17 +455,17 @@ lw_sock_recv_str_ex (int sock, char *str)
 	      log_flush ();
 	      break;
 	    case 0:
-	      log_print_int (sock);
+	      log_print_int (sock_copy);
 	      log_print_str (" < timeout!");
 	      log_println ();
 	      break;
 	    case -1:
-	      log_print_int (sock);
+	      log_print_int (sock_copy);
 	      log_print_str (" < closed!");
 	      log_println ();
 	      break;
 	    default:
-	      log_print_int (sock);
+	      log_print_int (sock_copy);
 	      log_print_str (" < unexpected error!");
 	      log_println ();
 	      break;
@@ -477,12 +482,13 @@ lw_sock_recv_str_ex (int sock, char *str)
  * Only a standard send wrapper
  */
 int
-lw_sock_send_buffer_ex (int sock, char *buffer, int len)
+lw_sock_send_buffer_ex (int *sock, char *buffer, int len)
 {
   int result = 0;
   char trace[LW_SOCK_MESSAGE_SIZE];
   fd_set write;
   struct timeval tv;
+  int sock_copy;
   int res;
   int total_sent;
   int sent;
@@ -490,22 +496,22 @@ lw_sock_send_buffer_ex (int sock, char *buffer, int len)
   int winerr;
 #endif
 
-  if (sock >= 0)
+  if ((sock_copy = *sock) >= 0)
     {
       result = 1;
 
       if (len <= LW_SOCK_MESSAGE_SIZE - 1)
 	{
 	  total_sent = 0;
-	  while (total_sent < len && result)
+	  while (total_sent < len && result && (sock_copy = *sock) >= 0)
 	    {
 	      FD_ZERO (&write);
-	      FD_SET (sock, &write);
+	      FD_SET (sock_copy, &write);
 	      tv.tv_sec = LW_SOCK_SEND_SEC;
 	      tv.tv_usec = LW_SOCK_SEND_USEC;
 
 	      errno = 0;
-	      res = select (sock + 1, NULL, &write, NULL, &tv);
+	      res = select (sock_copy + 1, NULL, &write, NULL, &tv);
 
 	      switch (res)
 		{
@@ -524,9 +530,9 @@ lw_sock_send_buffer_ex (int sock, char *buffer, int len)
 #endif
 		  break;
 		case 1:
-		  if (FD_ISSET (sock, &write))
+		  if (FD_ISSET (sock_copy, &write))
 		    {
-		      sent = send (sock,
+		      sent = send (sock_copy,
 				   buffer + total_sent,
 				   MIN (len - total_sent,
 					LW_SOCK_SEND_BUFFER_SIZE), 0);
@@ -551,7 +557,7 @@ lw_sock_send_buffer_ex (int sock, char *buffer, int len)
 		{
 		  strncpy (trace, buffer, len);
 		  trace[len] = '\0';
-		  log_print_int (sock);
+		  log_print_int (sock_copy);
 		  log_print_str (" > [");
 		  clean_buffer (trace, len);
 		  log_print_str (trace);
@@ -561,7 +567,7 @@ lw_sock_send_buffer_ex (int sock, char *buffer, int len)
 		}
 	      else
 		{
-		  log_print_int (sock);
+		  log_print_int (sock_copy);
 		  log_print_str (" > timeout!");
 		  log_println ();
 		}
@@ -572,7 +578,7 @@ lw_sock_send_buffer_ex (int sock, char *buffer, int len)
 	  result = 0;
 	  if (LW_SOCK_LOG)
 	    {
-	      log_print_int (sock);
+	      log_print_int (sock_copy);
 	      log_print_str (" > message too large!");
 	      log_println ();
 	    }
@@ -588,13 +594,14 @@ lw_sock_send_buffer_ex (int sock, char *buffer, int len)
  * Only a standard recv wrapper
  */
 int
-lw_sock_recv_buffer_ex (int sock, char *buffer, int len)
+lw_sock_recv_buffer_ex (int *sock, char *buffer, int len)
 {
   int result = 0;
   char trace[LW_SOCK_MESSAGE_SIZE];
   int res;
   fd_set read;
   struct timeval tv;
+  int sock_copy;
   int total_received;
   int received;
 #ifdef WIN32
@@ -603,22 +610,22 @@ lw_sock_recv_buffer_ex (int sock, char *buffer, int len)
 
   memset (buffer, 0, len);
 
-  if (sock >= 0)
+  if ((sock_copy = *sock) >= 0)
     {
       result = 1;
 
       if (len <= LW_SOCK_MESSAGE_SIZE - 1)
 	{
 	  total_received = 0;
-	  while (total_received < len && result)
+	  while (total_received < len && result && (sock_copy = *sock) >= 0)
 	    {
 	      FD_ZERO (&read);
-	      FD_SET (sock, &read);
+	      FD_SET (sock_copy, &read);
 	      tv.tv_sec = LW_SOCK_RECV_SEC;
 	      tv.tv_usec = LW_SOCK_RECV_USEC;
 
 	      errno = 0;
-	      res = select (sock + 1, &read, NULL, NULL, &tv);
+	      res = select (sock_copy + 1, &read, NULL, NULL, &tv);
 
 	      switch (res)
 		{
@@ -637,9 +644,9 @@ lw_sock_recv_buffer_ex (int sock, char *buffer, int len)
 #endif
 		  break;
 		case 1:
-		  if (FD_ISSET (sock, &read))
+		  if (FD_ISSET (sock_copy, &read))
 		    {
-		      received = recv (sock,
+		      received = recv (sock_copy,
 				       buffer + total_received,
 				       MIN (len - total_received,
 					    LW_SOCK_RECV_BUFFER_SIZE), 0);
@@ -664,7 +671,7 @@ lw_sock_recv_buffer_ex (int sock, char *buffer, int len)
 		{
 		  strncpy (trace, buffer, len);
 		  trace[len] = '\0';
-		  log_print_int (sock);
+		  log_print_int (sock_copy);
 		  log_print_str (" < [");
 		  clean_buffer (trace, len);
 		  log_print_str (trace);
@@ -674,7 +681,7 @@ lw_sock_recv_buffer_ex (int sock, char *buffer, int len)
 		}
 	      else
 		{
-		  log_print_int (sock);
+		  log_print_int (sock_copy);
 		  log_print_str (" < timeout!");
 		  log_println ();
 		}
@@ -685,7 +692,7 @@ lw_sock_recv_buffer_ex (int sock, char *buffer, int len)
 	  result = 0;
 	  if (LW_SOCK_LOG)
 	    {
-	      log_print_int (sock);
+	      log_print_int (sock_copy);
 	      log_print_str (" < message too large!");
 	      log_println ();
 	    }
