@@ -22,7 +22,7 @@
 
 /*****************************************************************************/
 /* Liquid War is a multiplayer wargame                                       */
-/* Copyright (C) 1998-2005 Christian Mauduit                                 */
+/* Copyright (C) 1998-2007 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -36,9 +36,9 @@
 /*                                                                           */
 /* You should have received a copy of the GNU General Public License         */
 /* along with this program; if not, write to the Free Software               */
-/* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
+/* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 /*                                                                           */
-/* Liquid War homepage : http://www.ufoot.org/liquidwar                      */
+/* Liquid War homepage : http://www.ufoot.org/liquidwar/v5                   */
 /* Contact author      : ufoot@ufoot.org                                     */
 /*****************************************************************************/
 
@@ -187,6 +187,7 @@ lw_sock_accept (int *new_sock, char *ip, int *port,
   int res;
   int enable = 1;
   int disable = 0;
+  unsigned long disable_ul = 0;
   struct linger li;
 
   *new_sock = -1;
@@ -223,7 +224,7 @@ lw_sock_accept (int *new_sock, char *ip, int *port,
 	      setsockopt (*new_sock, SOL_SOCKET, SO_LINGER,
 			  (char *) &li, sizeof (struct linger));
 
-	      ioctlsocket (*new_sock, FIONBIO, &disable);
+	      ioctlsocket (*new_sock, FIONBIO, &disable_ul);
 
 	      strncpy (ip, inet_ntoa (name.sin_addr), LW_SOCK_IP_SIZE - 1);
 	      ip[LW_SOCK_IP_SIZE - 1] = 0;
@@ -250,6 +251,7 @@ lw_sock_connect (int *sock, char *ip, int port)
   struct sockaddr_in name;
   int enable = 1;
   int disable = 0;
+  unsigned long disable_ul = 0;
   struct linger li;
 
   *sock = socket (AF_INET, SOCK_STREAM, 0);
@@ -278,7 +280,7 @@ lw_sock_connect (int *sock, char *ip, int port)
 	      setsockopt (*sock, SOL_SOCKET, SO_LINGER,
 			  (char *) &li, sizeof (struct linger));
 
-	      ioctlsocket (*sock, FIONBIO, &disable);
+	      ioctlsocket (*sock, FIONBIO, &disable_ul);
 
 	      result = 1;
 	    }
