@@ -22,7 +22,7 @@
 
 /*****************************************************************************/
 /* Liquid War is a multiplayer wargame                                       */
-/* Copyright (C) 1998-2004 Christian Mauduit                                 */
+/* Copyright (C) 1998-2007 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -36,9 +36,9 @@
 /*                                                                           */
 /* You should have received a copy of the GNU General Public License         */
 /* along with this program; if not, write to the Free Software               */
-/* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
+/* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 /*                                                                           */
-/* Liquid War homepage : http://www.ufoot.org/liquidwar                      */
+/* Liquid War homepage : http://www.ufoot.org/liquidwar/v5                   */
 /* Contact author      : ufoot@ufoot.org                                     */
 /*****************************************************************************/
 
@@ -130,7 +130,7 @@ start_water (void)
       LOCK_VARIABLE (WATER_VOLUME);
       LOCK_VARIABLE (SOUND_VOLUME_VALUES);
 
-#ifdef ALLEGRO_DOS
+#ifdef DOS
       _go32_dpmi_lock_data (HASARD_VALUE, HASARD_SIZE * sizeof (int));
       _go32_dpmi_lock_data (SOUND_VOLUME_VALUES, 17 * sizeof (int));
 #endif
