@@ -22,7 +22,7 @@
 
 /*****************************************************************************/
 /* Liquid War is a multiplayer wargame                                       */
-/* Copyright (C) 1998-2004 Christian Mauduit                                 */
+/* Copyright (C) 1998-2007 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -36,9 +36,9 @@
 /*                                                                           */
 /* You should have received a copy of the GNU General Public License         */
 /* along with this program; if not, write to the Free Software               */
-/* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
+/* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 /*                                                                           */
-/* Liquid War homepage : http://www.ufoot.org/liquidwar                      */
+/* Liquid War homepage : http://www.ufoot.org/liquidwar/v5                   */
 /* Contact author      : ufoot@ufoot.org                                     */
 /*****************************************************************************/
 
@@ -60,7 +60,7 @@
 /* variables globales                                               */
 /*==================================================================*/
 
-#ifdef ALLEGRO_DOS
+#ifdef DOS
 #define TICKER_STEP 5
 #else
 #define TICKER_STEP 10
@@ -90,7 +90,7 @@ int
 start_ticker (void)
 {
   int result = 0;
-  //#ifdef ALLEGRO_DOS
+  //#ifdef DOS
   LOCK_FUNCTION (ticker_handler);
   LOCK_VARIABLE (TICKER_VALUE);
 
@@ -103,7 +103,7 @@ start_ticker (void)
 void
 stop_ticker (void)
 {
-  //#ifdef ALLEGRO_DOS
+  //#ifdef DOS
   remove_int (ticker_handler);
   //#endif
 }
@@ -112,7 +112,7 @@ stop_ticker (void)
 int
 get_ticker (void)
 {
-  //#ifdef ALLEGRO_DOS
+  //#ifdef DOS
   return TICKER_VALUE;
   //#else
   //return ++TICKER_VALUE;
