@@ -1,13 +1,6 @@
 /*
 * Random circles.
 *
-* THIS HAS THE POSSIBLITY OF CREATING TRAPS!!!!
-* It happens if r & c differ by around 10 or more.
-*
-* Note: I think I fixed it... I changed size to pick the smaller.
-* If that doesn't work may have to force r & c to be the same
-* or just test each direction(N,E,S,W) for overlapping sections.
-*
 * Copyright (C) 2003, David Redick
 * Released under the GNU General Public License (v2)
 */
@@ -18,17 +11,14 @@
 void circles()
 {
      int r, c;
-     int width, height;
      int centerx, centery;
      int radius;
      int size;
 
 
-     section_size(&width, &height);
-
      /* whats the max radius */
-     size = (width < height ? width : height)/2;
-
+     size = (map.sec_width < map.sec_height ? map.sec_width : map.sec_height)/2.0;
+     size = (size == 0 ? 1 : size);
 
      for( r = 0; r < map.num_row; r++ )
      {
