@@ -11,9 +11,13 @@
 
 func_t func[MAX_FUNC] =
 {
+     /* keep this first! */
+     { "rand_func", "Picks a random function.", rand_func },
+
      { "big_quad", "One big, solid quad that takes up most of the map.", big_quad },
      { "boxes", "A bunch of boxes of the same size.", boxes },
-     { "circles", "Random circles", circles },
+     { "bubbles", "Random bubbles.", bubbles },
+     { "circles", "Random circles.", circles },
      { "circuit", "A map that looks like a circuit board.", circuit },
      { "hole", "Randomly shaped hole.", hole },
      { "lines", "A grid of random lines.", lines },
