@@ -8,10 +8,12 @@
 #ifndef LWMAPGEN_MAP_H
 #define LWMAPGEN_MAP_H
 
-#include "allegro.h"
+
+#include <allegro.h>
 #include "func.h"
 #include "misc.h"
 
+#define ALLEGRO_USE_CONSOLE
 
 extern char default_filename[10];
 
