@@ -8,6 +8,7 @@
 #include "map.h"
 #include "misc.h"
 
+#define PAD     5
 
 void rand_poly()
 {
@@ -27,7 +28,7 @@ void rand_poly()
      r = 0;
      for( c = 0; c < map.num_col; c++ )
      {
-          rand_point_section_offset(&vert[v], &vert[v+1], r, c, MAX_PAD);
+          rand_point_section_offset(&vert[v], &vert[v+1], r, c, PAD);
           v += 2;
      }
 
@@ -36,7 +37,7 @@ void rand_poly()
      c = map.num_col-1;
      for( r = 1; r < map.num_row; r++ )
      {
-          rand_point_section_offset(&vert[v], &vert[v+1], r, c, MAX_PAD);
+          rand_point_section_offset(&vert[v], &vert[v+1], r, c, PAD);
           v += 2;
      }
 
@@ -45,7 +46,7 @@ void rand_poly()
      r = map.num_row-1;
      for( c = map.num_col-2; c >= 0; c-- )
      {
-          rand_point_section_offset(&vert[v], &vert[v+1], r, c, MAX_PAD);
+          rand_point_section_offset(&vert[v], &vert[v+1], r, c, PAD);
           v += 2;
      }
 
@@ -54,7 +55,7 @@ void rand_poly()
      c = 0;
      for( r = map.num_row-2; r >= 1; r-- )
      {
-          rand_point_section_offset(&vert[v], &vert[v+1], r, c, MAX_PAD);
+          rand_point_section_offset(&vert[v], &vert[v+1], r, c, PAD);
           v += 2;
      }
 
